#
#-------------------------------------------------------------------------------
# @(#) motorola-bss/tech_pack_support/Motorola_BSS/GSR8/UserConfig.pm motorola-bss_r3.0.0.latest:cset.002547:2:2@(#)
#-------------------------------------------------------------------------------
#
# This perl module contains the configuration information for this parser.
# If you don't understand the format of this configuration file DON'T TOUCH IT.
#
# Motorola BSS CSV Parser
# 
# Copyright (c) 2007 Vallent Software Systems. All rights reserved.
#
package UserConfig;


@ISA = qw(Exporter);
@EXPORT = qw(postparser_config);

#use diagnostics;
use strict;
use Exporter ();


#-------------------------------------------------------------------------------

my @rules = (

{
        'RULE_TYPE' => 'JOIN',
        'RULE_DESC' => 'Merging cell_stats, cell_stats2 and cgprs_stats',
        'INPUT_FILE_DESCRIPTION' => [ '^cell_stats[\.\_](\w+)\.{0,1}(\w*)\.(\d{1,2}\w{3,4}\d{4})\.(\d{2}[\_:]\d{2}[\_:]\d{2})\.(\d+)-#-I.pif$',
                                      '^cell_(stats[0-9])[\.\_](\w+)\.{0,1}(\w*)\.(\d{1,2}\w{3,4}\d{4})\.(\d{2}[\_:]\d{2}[\_:]\d{2})\.(\d+)-#-I.pif$',
										'^carrier_stats[\.\_]\w+\.{0,1}\d{1,2}\w{3,4}\d{4}\..+-I-#-(.+)-#-FS-#-RSZ-#-CARRIER_STATS_AGG-#-A.pif$'],
                                      #'^(.*)cgprs_stats.*-#-I.pif' ],
       'PRODUCE_PIF' => 'True',
       'OUTPUT_FORMAT' => 'LIF_Writer',
       'OUTPUT_BLOCK_NAME' => 'cell_stats',
       'COUNTERS_TO_JOIN_ON' => ['nodeid', 'cellid'],
       'OUTPUT_FILENAME_START' => 'all_cell', 
       'HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME' => ['FILENAME' ],
},


{
        RULE_TYPE => 'PERLIZE',
        RULE_DESC => 'Unpacking cellid to LACID',
       
        INPUT_FILE_DESCRIPTION => '^all_cell.*-#-J.pif',
        DATA_COUNTERS_OP => sub
        {
            my $c_ref = shift;
            # create a holding counter
            my $tmp = $c_ref->{cellid};
            $tmp = substr($tmp,0) ;
            $c_ref->{lacid} = substr($tmp,1,3) ;

            # all okay
            return 0;
        },
        FILENAME_SUFFIX                  => 'PL',
        OUTPUT_FORMAT                    => "LIF_Writer",
        PRODUCE_PIF                      => 'TRUE',
  		OUTPUT_BLOCK_NAME              => 'cell_stats',
},


{
	
	RULE_TYPE              	 => 'BATCHFILES',
	RULE_DESC              	 => 'Batching AXCDR Measurements to LIF format',

	INPUT_FILE_DESCRIPTION => ['^axcdr_(stats|statistics)[\.\_](\w+)\.{0,1}(\w*)\.(\d{1,2}\w{3,4}\d{4})\.(\d{2}[\_:]\d{2}[\_:]\d{2})\.(\d+)*-#-I.pif$'],        
	PRODUCE_PIF            	 => 0,
	PRODUCE_LIF            	 => 'True',
	OUTPUT_BLOCK_NAME              => 'axcdr_statistics',
    OUTPUT_FILENAME_START          => 'axcdr_statistics',    
},


{
        RULE_TYPE                      => 'BATCHFILES',
        RULE_DESC                      => 'Batching BSS Stats Measurements to LIF format',
        
        INPUT_FILE_DESCRIPTION => ['^bss_(stats|statistics)[\.\_](\w+)\.{0,1}(\w*)\.(\d{1,2}\w{3,4}\d{4})\.(\d{2}[\_:]\d{2}[\_:]\d{2})\.(\d+)*-#-I.pif$'],        
        
        PRODUCE_PIF                    => '0',
        PRODUCE_LIF                    => 'True',
        OUTPUT_BLOCK_NAME              => 'bss_statistics',
        OUTPUT_FILENAME_START          => 'bss_statistics',
},


{
        RULE_TYPE                      => 'BATCHFILES',
        RULE_DESC                      => 'Batching CBL Stats Measurements to LIF format',
        
        INPUT_FILE_DESCRIPTION => ['^cbl_(stats|statistics)[\.\_](\w+)\.{0,1}(\w*)\.(\d{1,2}\w{3,4}\d{4})\.(\d{2}[\_:]\d{2}[\_:]\d{2})\.(\d+)*-#-I.pif$'],        
        PRODUCE_PIF                    => 0,
        PRODUCE_LIF                    => 'True',
        OUTPUT_BLOCK_NAME              => 'cbl_statistics',
        HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
        OUTPUT_FILENAME_START          => 'cbl_statistics',
},

{
        RULE_TYPE                      => 'BATCHFILES',
        RULE_DESC                      => 'Batching DPROC Stats Measurements to LIF format',
        
        INPUT_FILE_DESCRIPTION => ['^dproc_(stats|statistics)[\.\_](\w+)\.{0,1}(\w*)\.(\d{1,2}\w{3,4}\d{4})\.(\d{2}[\_:]\d{2}[\_:]\d{2})\.(\d+)*-#-I.pif$'],        
        
        PRODUCE_PIF                    => 0,
        PRODUCE_LIF                    => 'True',
        OUTPUT_BLOCK_NAME              => 'dproc_statistics',
        OUTPUT_FILENAME_START          => 'dproc_statistics',
},

{
        RULE_TYPE                      => 'BATCHFILES',
        RULE_DESC                      => 'Batching DYNETGP Stats Measurements to LIF format',
        
        INPUT_FILE_DESCRIPTION => ['^dynetgp_(stats|statistics)[\.\_](\w+)\.{0,1}(\w*)\.(\d{1,2}\w{3,4}\d{4})\.(\d{2}[\_:]\d{2}[\_:]\d{2})\.(\d+)*-#-I.pif$'],        
        PRODUCE_PIF                    => 0,
        PRODUCE_LIF                    => 'True',
        OUTPUT_BLOCK_NAME              => 'dynetgp_statistics',
        HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
        OUTPUT_FILENAME_START          => 'dynetgp_statistics',
},

{
        RULE_TYPE                      => 'BATCHFILES',
        RULE_DESC                      => 'Batching GBL Stats Measurements to LIF format',
        
        INPUT_FILE_DESCRIPTION => ['^gbl_(stats|statistics)[\.\_](\w+)\.{0,1}(\w*)\.(\d{1,2}\w{3,4}\d{4})\.(\d{2}[\_:]\d{2}[\_:]\d{2})\.(\d+)*-#-I.pif$'],        
        
        PRODUCE_PIF                    => 0,
        PRODUCE_LIF                    => 'True',
        OUTPUT_BLOCK_NAME              => 'gbl_statistics',
        OUTPUT_FILENAME_START          => 'gbl_statistics',
},

{
        RULE_TYPE                      => 'BATCHFILES',
        RULE_DESC                      => 'Batching BSS Stats Measurements to LIF format',
        
        INPUT_FILE_DESCRIPTION => ['^gproc_(stats|statistics)[\.\_](\w+)\.{0,1}(\w*)\.(\d{1,2}\w{3,4}\d{4})\.(\d{2}[\_:]\d{2}[\_:]\d{2})\.(\d+)*-#-I.pif$'],        
        
        PRODUCE_PIF                    => 0,
        PRODUCE_LIF                    => 'True',
        OUTPUT_BLOCK_NAME              => 'gproc_statistics',
        OUTPUT_FILENAME_START          => 'gproc_statistics',
},

{
        RULE_TYPE                      => 'BATCHFILES',
        RULE_DESC                      => 'Batching GSL Stats Measurements to LIF format',
        
        INPUT_FILE_DESCRIPTION => ['^gsl_(stats|statistics)[\.\_](\w+)\.{0,1}(\w*)\.(\d{1,2}\w{3,4}\d{4})\.(\d{2}[\_:]\d{2}[\_:]\d{2})\.(\d+)*-#-I.pif$'],        
        PRODUCE_PIF                    => 0,
        PRODUCE_LIF                    => 'True',
        OUTPUT_BLOCK_NAME              => 'gsl_statistics',
        OUTPUT_FILENAME_START          => 'gsl_statistics',
},

{
        RULE_TYPE                      => 'BATCHFILES',
        RULE_DESC                      => 'Batching LMTL Stats Measurements to LIF format',
        
        INPUT_FILE_DESCRIPTION => ['^lmtl_(stats|statistics)[\.\_](\w+)\.{0,1}(\w*)\.(\d{1,2}\w{3,4}\d{4})\.(\d{2}[\_:]\d{2}[\_:]\d{2})\.(\d+)*-#-I.pif$'],        
        
        PRODUCE_PIF                    => 0,
        PRODUCE_LIF                    => 'True',
        OUTPUT_BLOCK_NAME              => 'lmtl_statistics',
        OUTPUT_FILENAME_START          => 'lmtl_statistics',
},


{
        RULE_TYPE                      => 'BATCHFILES',
        RULE_DESC                      => 'Batching MTL Stats Measurements to LIF format',
        
        INPUT_FILE_DESCRIPTION => ['^mtl_(stats|statistics)[\.\_](\w+)\.{0,1}(\w*)\.(\d{1,2}\w{3,4}\d{4})\.(\d{2}[\_:]\d{2}[\_:]\d{2})\.(\d+)*-#-I.pif$'],        
        PRODUCE_PIF                    => 0,
        PRODUCE_LIF                    => 'True',
        OUTPUT_BLOCK_NAME              => 'mtl_statistics',
        HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
        OUTPUT_FILENAME_START          => 'mtl_statistics',
},


{
        RULE_TYPE                      => 'BATCHFILES',
        RULE_DESC                      => 'Batching nbr Stats Measurements to LIF format',
        
        INPUT_FILE_DESCRIPTION => ['^nbr_(stats|statistics)[\.\_](\w+)\.{0,1}(\w*)\.(\d{1,2}\w{3,4}\d{4})\.(\d{2}[\_:]\d{2}[\_:]\d{2})\.(\d+)*-#-I.pif$'],        
        PRODUCE_PIF                    => 0,
        PRODUCE_LIF                    => 'True',
        OUTPUT_BLOCK_NAME              => 'nbr_stats',
        OUTPUT_FILENAME_START          => 'nbr_stats',
},


{
        RULE_TYPE                      => 'BATCHFILES',
        RULE_DESC                      => 'Batching OML Stats Measurements to LIF format',
        
        INPUT_FILE_DESCRIPTION => ['^oml_(stats|statistics)[\.\_](\w+)\.{0,1}(\w*)\.(\d{1,2}\w{3,4}\d{4})\.(\d{2}[\_:]\d{2}[\_:]\d{2})\.(\d+)*-#-I.pif$'],        
        PRODUCE_PIF                    => 0,
        PRODUCE_LIF                    => 'True',
        OUTPUT_BLOCK_NAME              => 'oml_statistics',
        HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
        OUTPUT_FILENAME_START          => 'oml_statistics',
},


{
        RULE_TYPE                      => 'BATCHFILES',
        RULE_DESC                      => 'Batching RSL Stats Measurements to LIF format',
        
        INPUT_FILE_DESCRIPTION => ['^rsl_(stats|statistics)[\.\_](\w+)\.{0,1}(\w*)\.(\d{1,2}\w{3,4}\d{4})\.(\d{2}[\_:]\d{2}[\_:]\d{2})\.(\d+)*-#-I.pif$'],        
        PRODUCE_PIF                    => '0',
        PRODUCE_LIF                    => 'True',
        OUTPUT_BLOCK_NAME              => 'rsl_statistics',
        OUTPUT_FILENAME_START          => 'rsl_statistics',
},

{
        RULE_TYPE                      => 'BATCHFILES',
        RULE_DESC                      => 'Batching XBL Stats Measurements to LIF format',
        
        INPUT_FILE_DESCRIPTION => ['^xbl_(stats|statistics)[\.\_](\w+)\.{0,1}(\w*)\.(\d{1,2}\w{3,4}\d{4})\.(\d{2}[\_:]\d{2}[\_:]\d{2})\.(\d+)*-#-I.pif$'],        
        PRODUCE_PIF                    => 0,
        PRODUCE_LIF                    => 'True',
        OUTPUT_BLOCK_NAME              => 'xbl_statistics',
        HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
        OUTPUT_FILENAME_START          => 'xbl_statistics',
},

{
        RULE_TYPE => 'PIF_REMOVE',
        RULE_DESC => 'Remove all but carrier stat files',
        INPUT_FILE_DESCRIPTION => [ '^.*cbl_statistics.*-#-I.pif',
                                    '^.*axcdr_statistics.*-#-I.pif', 
                                    '^.*bss_statistics.*-#-I.pif', 
                                    '^.*cbl_statistics.*-#-I.pif', 
                                    '^.*cell_ho.*-#-I.pif', 
                                    '^.*dproc_statistics.*-#-I.pif', 
                                    '^.*dynetgp_statistics.*-#-I.pif', 
                                    '^.*gbl_statistics.*-#-I.pif', 
                                    '^.*gproc_statistics.*-#-I.pif', 
                                    '^.*gsl_statistics.*-#-I.pif', 
                                    '^.*lmtl_statistics.*-#-I.pif', 
                                    '^.*mtl_statistics.*-#-I.pif', 
                                    '^.*nbr_stats.*-#-I.pif', 
                                    '^.*oml_statistics.*-#-I.pif', 
                                    '^.*rsl_statistics.*-#-I.pif', 
                                    '^.*xbl_statistics.*-#-I.pif', 
                                  ],
},

###################################################################################################
#
# TRX Carriers Stats - Cell Level 
#
# It's possible to have 1 rule for all 4 carrier types, but it seems that the subsequent JOIN
# rule filters out the NUM_IN_SUM counter(s), so I have different aggregation counters.
#
###################################################################################################
# Aggregation Of Carrier Stats to Cell Level
{
		## 1st accumulation of carrier - Accumulation of carrier statistics
	
        RULE_TYPE              => 'ACCUMULATE',
        RULE_DESC              => 'Aggregate Carrier Stats',
        PRODUCE_PIF            => 'True',

        PRODUCE_LIF			   => '0',
        OUTPUT_BLOCK_NAME      => 'carrier_stats',
        
        INPUT_FILE_DESCRIPTION => ['^carrier_(stats|statistics)[\.\_](\w+)\.{0,1}(\w*)\.(\d{1,2}\w{3,4}\d{4})\.(\d{2}[\_:]\d{2}[\_:]\d{2})\.(\d+)*-#-I.pif$'],        

        COUNTERS_TO_SORT_ON    => ['cellid'],
        
        NON_ADDITIVE_COUNTERS  => ['btsid', 'day', 'start', 'DURATION', 'end', 'nodeid','cellid','cellname','carrierid','gsmcellid'],
        REDUNDANT_COUNTERS     => ['carrid'],
        OUTPUT_FILENAME_START          => 'carrier_stats',
},


{
        RULE_TYPE                      => 'BATCHFILES',        
        RULE_DESC                      => 'Batching Carrier files',

        INPUT_FILE_DESCRIPTION => ['carrier_stats[\.\_](\w+)\.{0,1}(\w*)\.(\d{1,2}\w{3,4}\d{4})\.(\d{2}[\_:]\d{2}[\_:]\d{2})\.(\d+)-#-I-#-carrier_stats-#-A.pif$'],
        
        PRODUCE_PIF                    => 0,
        PRODUCE_LIF                    => 'True',
        OUTPUT_BLOCK_NAME              => 'carrier_stats',
        OUTPUT_FILENAME_START          => 'carrier_stats',
},


{
        RULE_TYPE              => 'ACCUMULATE',
        RULE_DESC              => 'Aggregate Carrier Stats 1',
        PRODUCE_PIF            => '0',
        PRODUCE_LIF			   => 'True',
        
        OUTPUT_BLOCK_NAME      => 'carrier_stats1',
        
        INPUT_FILE_DESCRIPTION => ['^.*carrier_stats?1.*-#-I.pif'],
        
        COUNTERS_TO_SORT_ON    => ['cellid'],
         
        NON_ADDITIVE_COUNTERS  => ['btsid', 'DURATION', 'start', 'end'],
        REDUNDANT_COUNTERS     => ['carrid'],        
},


# Aggregation Of Carrier Stats 2
{
        RULE_TYPE              => 'ACCUMULATE',
        RULE_DESC              => 'Aggregate Carrier Stats 2',
        PRODUCE_PIF            => 'True',
        PRODUCE_LIF			   => 'True',
        
        OUTPUT_BLOCK_NAME      => 'carrier_stats2',
       
        INPUT_FILE_DESCRIPTION => ["^.*carrier_stats?2.*-#-I.pif"],       
        COUNTERS_TO_SORT_ON    => ['cellid'],
        
        NON_ADDITIVE_COUNTERS  => ['btsid', 'DURATION', 'start', 'end'],
        REDUNDANT_COUNTERS     => ['carrid'],
},


# Aggregation Of Carrier Stats 3
{
        RULE_TYPE              => 'ACCUMULATE',
        RULE_DESC              => 'Aggregate Carrier Stats 3',
        PRODUCE_PIF            => 'True',
        PRODUCE_LIF			   => 'True',
        
        OUTPUT_BLOCK_NAME      => 'carrier_stats3',
        
        INPUT_FILE_DESCRIPTION => ["^.*carrier_stats?3.*-#-I.pif"],
        
        COUNTERS_TO_SORT_ON    => ['cellid'],
        
        NON_ADDITIVE_COUNTERS  => ['btsid', 'DURATION', 'start', 'end'],
        REDUNDANT_COUNTERS     => ['carrid'],
},


# Aggregation Of Carrier Stats 4
{
        RULE_TYPE              => 'ACCUMULATE',
        RULE_DESC              => 'Aggregate Carrier Stats 4',
        PRODUCE_PIF            => 'True',
        PRODUCE_LIF            => 'True',
       	OUTPUT_BLOCK_NAME      => 'carrier_stats4',
       	  	
        INPUT_FILE_DESCRIPTION => ["^.*carrier_stats?4.*-#-I.pif"],
     
        COUNTERS_TO_SORT_ON    => ['cellid'],
        
        NON_ADDITIVE_COUNTERS  => ['btsid', 'DURATION', 'start', 'end'],
        REDUNDANT_COUNTERS     => ['carrid'],
},


{
       RULE_TYPE => 'JOIN',
       RULE_DESC => 'Merging All Carrier Stats',

	   INPUT_FILE_DESCRIPTION => ['carrier_stat1\.(\w+)\.(\d{1,2}\w{3,4}\d{4})\.(\d{2}[\_:]\d{2}[\_:]\d{2})\.(\d+)-#-I-#-carrier_stats1-#-A.pif',
	   'carrier_stat2\.(\w+)\.(\d{1,2}\w{3,4}\d{4})\.(\d{2}[\_:]\d{2}[\_:]\d{2})\.(\d+)-#-I-#-carrier_stats2-#-A.pif',
	   'carrier_stat3\.(\w+)\.(\d{1,2}\w{3,4}\d{4})\.(\d{2}[\_:]\d{2}[\_:]\d{2})\.(\d+)-#-I-#-carrier_stats3-#-A.pif',
	   'carrier_stat4\.(\w+)\.(\d{1,2}\w{3,4}\d{4})\.(\d{2}[\_:]\d{2}[\_:]\d{2})\.(\d+)-#-I-#-carrier_stats4-#-A.pif' ],
	   
	   PRODUCE_PIF => 'True',
       PRODUCE_LIF => 'True',
       OUTPUT_BLOCK_NAME => 'carrier_stat_agg',
       
       COUNTERS_TO_JOIN_ON => ['nodeid', 'cellid', 'btsid'],
       OUTPUT_FILENAME_START => 'ALL_CARRIER',
       TIME_JOINFILE_PRODUCED => 'True',
       
       HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => ['FILENAME' ],
       QUOTE_INPUT_PIFS => 'True',
},


{
        RULE_TYPE => 'PIF_REMOVE',
        RULE_DESC => 'Remove all Carrier files',
        INPUT_FILE_DESCRIPTION => [ '^carrier_stat[s0-9]*[\.\_](\w+)\.{0,1}(\w*)\.(\d{1,2}\w{3,4}\d{4})\.(\d{2}[\_:]\d{2}[\_:]\d{2})\.(\d+)*-#-I.pif$' ],
},


{
        'RULE_TYPE' => 'JOIN',
        'RULE_DESC' => 'Merging all_cell, carrier_stats_agg',

        'INPUT_FILE_DESCRIPTION' => ['^all_cell-#-(\w+)\.(\w*)\.(\d{1,2}\w{3,4}\d{4})\.(\d{2}[\_:]\d{2}[\_:]\d{2})\.(\d+)-#-.*-#-J-#-PL.pif',
        							'^ALL_CARRIER-#-(.*)-#-.*-#-J.pif'],

      	'PRODUCE_PIF' => 'LIF_Writer',
       'PRODUCE_LIF' => 'True',
       'OUTPUT_BLOCK_NAME' => 'CELL_ALL',
       'COUNTERS_TO_JOIN_ON' => ['cellid'],
       'OUTPUT_FILENAME_START' => 'CELL_ALL',

        'HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME' => ['FILENAME'],
},

# Aggregation Of all_cell
{
        'RULE_TYPE'              => 'ACCUMULATE',
        'RULE_DESC'              => 'Aggregate all_cell',
        #'PRODUCE_PIF'            => '0',
        
        'PRODUCE_PIF' => 'LIF_Writer',
        'PRODUCE_LIF'            => 'True',
        'OUTPUT_FORMAT'            => 'LIF_Writer',
        'OUTPUT_BLOCK_NAME'      => 'BSC_ALL',
        'OUTPUT_FILENAME_START' => 'BSC_ALL',
        'INPUT_FILE_DESCRIPTION' => ["^all_cell-#-.*-#-.*-#-J-#-PL.pif"],
        #'INPUT_FILE_DESCRIPTION' => ['all_cell-#-(\w+)\.(\w*)\.(\d{1,2}\w{3,4}\d{4})\.(\d{2}[\_:]\d{2}[\_:]\d{2})\.(\d+)-#-.*-#-J-#-PL-#-BSC_ALL-#-A.pif'],
        'COUNTERS_TO_SORT_ON'    => ['nodeid'],
        
        'NON_ADDITIVE_COUNTERS'  => ['btsid', 'DURATION','start','end','day'],
        'REDUNDANT_COUNTERS'     => ['cellid', 'lacid'],
},

#-------------------------------------------------------------------------------
);  

#-------------------------------------------------------------------------------

sub postparser_config {
	return \@rules;
}

1;

